#
# spec file for package sof-firmware
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _firmwaredir /lib/firmware
%endif

Name:           sof-firmware
Summary:        Firmware data files for SOF Drivers
License:        BSD-3-Clause
Group:          Hardware/Other
Version:        2025.01.1
Release:        1.1
URL:            https://www.sofproject.org/
BuildRequires:  fdupes
Requires(post): coreutils
Source:         https://github.com/thesofproject/sof-bin/releases/download/v%{version}/sof-bin-%{version}.tar.gz
Patch1:         install-use-cp.patch
BuildArch:      noarch
# snd-sof-pci-intel-apl
Supplements:    modalias(pci:v00008086d00003198sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00005A98sv*sd*bc*sc*i*)
# snd-sof-pci-intel-cnl
Supplements:    modalias(pci:v00008086d0000A3F0sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000002C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000006C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00009DC8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000A348sv*sd*bc*sc*i*)
# snd-sof-pci-intel-icl
Supplements:    modalias(pci:v00008086d00004DC8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000034C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000038C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00003DC8sv*sd*bc*sc*i*)
# snd-sof-pci-intel-lnl
Supplements:    modalias(pci:v00008086d0000A828sv*sd*bc*sc*i*)
# snd-sof-pci-intel-mtl
Supplements:    modalias(pci:v00008086d00007728sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00007E28sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00007F50sv*sd*bc*sc*i*)
# snd-sof-pci-intel-ptl
Supplements:    modalias(pci:v00008086d0000E328sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000E428sv*sd*bc*sc*i*)
# snd-sof-pci-intel-skl
Supplements:    modalias(pci:v00008086d00009D71sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00009D70sv*sd*bc*sc*i*)
# snd-sof-pci-intel-tgl
Supplements:    modalias(pci:v00008086d000054C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000043C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00004B55sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00004B58sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051C8sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051C9sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CAsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CBsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CCsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CDsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CEsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d000051CFsv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00007A50sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d00007AD0sv*sd*bc*sc*i*)
Supplements:    modalias(pci:v00008086d0000A0C8sv*sd*bc*sc*i*)
# snd-sof-pci-intel-tng
Supplements:    modalias(pci:v00008086d0000119Asv*sd*bc*sc*i*)
# snd-sof-acpi-intel-bdw
Supplements:    modalias(acpi*:INT3438%3A*)
# snd-sof-acpi-intel-byt
Supplements:    modalias(acpi*:808622A8%3A*)
Supplements:    modalias(acpi*:80860F28%3A*)
# snd-sof-amd-acp-*
Supplements:    modalias(pci:v00001022d000015E2sv*sd*bc*sc*i*)
%if 0%{?suse_version} >= 1550
# make sure we have post-usrmerge filesystem package on TW
Conflicts:      filesystem < 84
%endif

%description
Firmware data files for Sound Open Firmware (SOF) drivers.

%prep
%autosetup -p1 -n sof-bin-%{version}

%build

%install
mkdir -p %{buildroot}%{_firmwaredir}/intel
mkdir -p %{buildroot}%{_bindir}
FW_DEST=%{buildroot}%{_firmwaredir}/intel \
TOOLS_DEST=%{buildroot}%{_bindir} \
./install.sh
rm -rf %{buildroot}%{_bindir}

# A workaround for a symlinked directory sof-ace-tplg:
# it was a real directory in the earlier versions, and now it's gone,
# and rpm doesn't like the transition from a directory to a symlink at all.
# So we copy all stuff manually.  It's waste of resources, but that's life
rm %{buildroot}%{_firmwaredir}/intel/sof-ace-tplg
cp -a %{buildroot}%{_firmwaredir}/intel/sof-ipc4-tplg \
   %{buildroot}%{_firmwaredir}/intel/sof-ace-tplg

%fdupes -s %{buildroot}

# workaround for changing symlinked directory
%pre
if [ -L %{_firmwaredir}/intel/sof-tplg ]; then
  f=$(readlink -f %{_firmwaredir}/intel/sof-tplg)
  case $f in
    %{_firmwaredir}/intel/*)
      rm -rf $f
      rm -f %{_firmwaredir}/intel/sof-tplg;;
  esac
fi

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%license LICENCE.* Notice.NXP
%doc README.*
%{_firmwaredir}/*

%changelog
* Mon Apr 14 2025 Takashi Iwai <tiwai@suse.com>
- Update to v2025.01.1:
  * Fixes to ASUS Zenbook S 14 and S 16 bugs
  * topology backports for Intel LNL systems
  * topology2: add sof-lnl-cs42l43-l0-cs35l56-l23-4ch
- Update supplements
* Wed Feb 19 2025 Takashi Iwai <tiwai@suse.com>
- Update to v2025.01:
  * SOF v2.12 firmware and tools
  * New platforms: NXP IMX95
  * Zephyr RTOS support added: AMD ACP6.0, MediaTek 8195/86/88
  * HIFI5 optimization added to multiple components: IIR core, ARIA and volume
  * Zephyr loadable module (LLEXT) support extended in SOF with capability to handle libraries of loadable modules
  * Support added to mark module functions as "cold", allowing code to be run directly from DRAM and save on SRAM usage on platforms supporting the feature
  * Topology: support for new product configurations for Intel LNL/ARL/MTL and NXP IMX95
  * Topology: microphone (IIR and DRC) and speaker processing (IIR, FIR and DRC) added to Intel DSP topologies with Soundwire codecs.
- Update alias for snd-sof-pci-intel-ptl
* Thu Jan  2 2025 Takashi Iwai <tiwai@suse.com>
- update to v2024.09.02: (jsc#PED-9993 jsc#PED-10202)
  * Updated DSP topology files for SOF2.11.3
* Wed Nov 13 2024 Takashi Iwai <tiwai@suse.com>
- update to v2024.09.1: (jsc#PED-9993 jsc#PED-10202)
  * Add missing links for SOF v2.11.1 signed Intel binaries for ARL
  * fixup the intel-signed/sof-arl.ri link
  * Update v2.2.12 topology files for Intel platforms
  * add new 2.11.2 topology2 production binaries
* Tue Oct  1 2024 Takashi Iwai <tiwai@suse.com>
- update to v2024.09: (jsc#PED-9993 jsc#PED-10202)
  * Add sof-v2.11 binaries
  * v2.2.x: Update v2.2.11 topology files for Intel platforms
  * Add sof-v2.11.1 binaries for Intel TGL/ADL/RPL hardware
* Thu Jul 25 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.06: (bsc#1230236)
  * Add SOF v2.9 signed binaries for Intel Arrow Lake S
  * Add sof-v2.10 for Intel hardware
  * Add SOF v2.10 signed Intel binaries
  * v2.10.x: remove extra sof-rpl.ri
* Fri May 10 2024 Takashi Iwai <tiwai@suse.com>
- Add a workaround for installation error due to the change of
  intel/sof-ace-tplg directory to a symlink
* Thu May  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.03:
  * For v2.9 series, the following new topology files have been
    added since v2.8:
    v2.9.x/sof-ipc4-tplg-v2.9
    ├── sof-hda-generic-ace1-2ch.tplg
    ├── sof-hda-generic-ace1-4ch.tplg
    ├── sof-hda-generic-cavs25-2ch.tplg
    ├── sof-hda-generic-cavs25-4ch.tplg
    ├── sof-mtl-es83x6-ssp1-hdmi-ssp02.tplg
    ├── sof-mtl-hdmi-ssp02.tplg
  * For v2.2.8 series, the following new topology files have been
    added since v2.2.8
    ├── sof-adl-es8336-ssp1-hdmi-ssp02-4ch.tplg
    └── sof-adl-sdw-cs42l42-4ch.tplg
* Wed Mar 27 2024 Takashi Iwai <tiwai@suse.com>
- Updated to version 2023.12.1:
  * SOF v2.8.1 FW binaries. For older Intel platforms, FW from v2.2 stable
  * SOF v2.8 tools. For older Intel platforms, tools from v2.2 stable
  * SOF v2.8.1 DSP topologies. For older Intel platforms, topologies matching v2.2.8
- Update supplements for snd-sof-pci-intel-mtl
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Jan  2 2024 Takashi Iwai <tiwai@suse.com>
- Update to version 2023.12:
  * SOF v2.8 FW binaries: For older Intel platforms, FW from v2.2 stable
  * SOF v2.8 tools: For older Intel platforms, tools from v2.2 stable
  * SOF v2.8 DSP topologies: For older Intel platforms, topologies matching v2.2.8
* Tue Dec 26 2023 Giacomo Comes <gcomes.obs@gmail.com>
- add Requires(post): coreutils
  * the macro regenerate_initrd_post creates a post scriptlet that
    uses mkdir and touch
* Fri Dec 15 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2023.09.02:
  updates for Intel Meteor Lake (jsc#PED-6123,jsc#PED-6114,
  jsc#PED-6104,jsc#PED-6067,jsc#PED-6045,jsc#PED-6036)
* Tue Nov 14 2023 Takashi Iwai <tiwai@suse.com>
- Update Supplements for new modules like AMD ACP
* Thu Nov  9 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2023.09.1:
  fixes for Intel Meteor Lake platforms (jsc#PED-6123,jsc#PED-6114,
  jsc#PED-6104,jsc#PED-6067,jsc#PED-6045,jsc#PED-6036)
* Mon Oct  9 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2023.09 (jsc#PED-6123,jsc#PED-6114,jsc#PED-6104,
  jsc#PED-6067,jsc#PED-6045,jsc#PED-6036):
  it's a combined tarball with different version to support multiple
  platforms including Metor Lake
- Use cp instead of rsync for installation:
  install-use-cp.patch
* Tue Jul 18 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2.2.6:
  There's no FW binary change. This release adds a few new topology binaries
  for Intel Tiger Lake (TGL), Alder Lake (ADL) and Raptor Lake (RPL) platforms
- Add Notice.NXP
* Mon Jun  5 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2.2.5:
  There's no FW binary change. This release adds a few new topology
  binaries for Intel Alder Lake (ADL) platforms.
- Update supplements for RPL and MTL
* Tue Jan 17 2023 Takashi Iwai <tiwai@suse.com>
- Update to version 2.2.3:
  ADL-N FW binary and topology updates for ADL/RPL/ICL
- Update to version 2.2.4:
  New topology binaries for RPL/ADL/JSL
- Fix modalias for ACPI (bsc#1207211)
* Thu Nov  3 2022 Takashi Iwai <tiwai@suse.com>
- Update to version 2.2.2:
  * Add support for Intel Raptor Lake (jsc#PED-850)
  * CAVS firmware files are dropped
* Sun Aug 28 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add sof-tplg-v2.2.1
  * https://github.com/thesofproject/sof/releases/tag/v2.2.1
  * topology updates for SoundWire, Intel APL/GLK platform with ES8336 codec,
    and Intel RPL platform
* Sun Jul 17 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to version 2.2:
  * New up mix and down mix module added with support for HiFi4
    that can up/down mix the number of channels in a stream.
  * Zephyr, more native APIs added now for logging, delays, sleeping.
  * Codec adapter becomes the module adapter and it's API reflects the
    same API used by the Windows processing modules
  * See details in https://github.com/thesofproject/sof/releases/tag/v2.2
* Wed Apr 20 2022 tiwai@suse.de
- Update to version 2.1:
  Mediatek MT8186, Google AEC and other new platforms.
  Stability improvements, etc.
  See details in
    https://github.com/thesofproject/sof/releases
- Update to version 2.1.1:
  a fix release for 2.1
- Update supplements for ADL-N
* Thu Jan 20 2022 tiwai@suse.de
- Update to version 2.0:
  Intel Alderlake support, lots of fixes, etc.
  See details in
    https://github.com/thesofproject/sof/releases
* Mon Jul 19 2021 tiwai@suse.de
- Update to version 1.8:
  * Improved support for Intel Tigerlake based devices.
  * Bluetooth support.
  * Support for Inteligo noise reduction technology.
  * Support for further Cadence library codecs.
  * Further performance improvements to audio processing library.
  * Power optimizations for Intel Tigerlake and Alderlake.
  * Usual bug fixes and stability improvements.
  * Pipeline level multi-core support
  * LL scheduler refinement for multi-core support
  * Zephyr integration continues with more native features being used.
  * Some known xrun issues with multi-core are fixed
  Note that, due to yet more conflict, we cannot use the file layout
  of the original tarball (the symlink sof-v1.8 -> sof would fail at
  updating a package), install to the flat layout instead manually;
  the script wouldn't work with the destination prefix, in anyway
- Update module aliases
- Drop obsoleted patch sof-bin-go-install-fix.patch
- Add conflicts with the non-usrmerge systems for TW package;
  just for avoiding pitfalls of non-working systems
- Fix download URL
* Wed Jun  2 2021 tiwai@suse.de
- Fix the build on TW after UsrMerge
- Drop the ugly workaround for the symlink fixups again, as we
  moved the base directory due to UsrMerge
* Tue Apr  6 2021 tiwai@suse.de
- Update to version 1.7:
  * Added support for Intel Tigerlake H
  * The codec adapter has had many improvements and now supports
    audio processing modules from Cadence
  * Continued Zephyr integration now means SOF is supported as a
    Zephyr module
  * Scheduler improvements to support dynamic clock switching
  * Major feature and performance improvements for Smart amplifiers,
    SRC, Mux, Crossover and DRC
  * Numerous bug fixes and performance improvements for Intel and
    NXP platforms
- Fix installation from v1.7 tarball:
  sof-bin-go-install-fix.patch
* Mon Feb  1 2021 tiwai@suse.de
- Yet more ugly workarounds for the rpm shortness about the symlink
  directory handling (bsc#1181554)
* Thu Jan 21 2021 tiwai@suse.de
- Update to version 1.6.1:
  * Stable fix releases
- Take the tarball from the github release
- Keep dropping the broken JSL links; the firmware is still missing
- Update supplements
* Mon Jan 18 2021 tiwai@suse.de
- Add an ugly workaround for the upgrade error from the old 1.6-rc3
  or older due to the rpm problem (bsc#1180287)
* Thu Dec 17 2020 tiwai@suse.de
- Update to version 1.6 final:
  * New platform JSL and EHL is added
- Use the bundled go.sh for installation
- Dropped jsl.ri that is wrongly symlinked for now
* Thu Nov 26 2020 tiwai@suse.de
- Fix build with older distros without %%_firmwaredir
* Tue Nov  3 2020 tiwai@suse.de
- Update to version 1.6-rc3 (bsc#1178306):
  * Support for Intel Tigerlake
  * Support for Maxim Smart Amplifiers
  * Beamformer Microphone support
  * DC blocker audio processing component
  * Major feature and performance improvements for ASRC, KWD and FIR/IIR
  * Numerous bug fixes and performance improvements for Intel and NXP
    platforms
* Mon Oct 19 2020 Ludwig Nussel <lnussel@suse.de>
- use %%_firmwaredir
* Mon Sep  7 2020 tiwai@suse.de
- Update to version 1.5.1 (bsc#1176200):
  * ipc: header size validation fix
  * ipc: check state in comp_free
  * Topology: HDA-generic: Use +20 dB EQ gain for 16 kHz DMIC capture
  * Topology: HDA-generic: Use +20 dB EQ gain for DMIC capture pipelines
  * topology: fix dmic names (again)
  * ssp: fix log
  * Audio: SRC: Fix build fail when only CONFIG_FORMAT_S16LE is set
  * cavs: platform: fix debug region size in FW ready
  * mux: trace: fix uuid name assigned to demux driver
  * platform: imx8m: Fix FIFO depth for i.MX8M
  * drivers: imx: Fix free/avail bytes in sdma_get_data_size
  * kpb: fix race condition in draining task
  * .travis.yml: Fix incorrect usage of -j option
  * topology: fix a typo for SCHEDULE_CORE
  * licence: Include NXP Copyright
  * Add TGL FW into v1.5.1 release
- Update modaliases for the new chipsets
* Mon Aug  3 2020 tiwai@suse.de
- Add missing symlink for Coffee Lake firmware, too (bsc#1174826)
* Tue Jun  9 2020 tiwai@suse.de
- Add some comments for avoid misunderstanding about the package
- Add missing symlink for CML firmware
- Avoid symlink for tplg directory that may cause an error at
  upgrading from the old package
* Thu Jun  4 2020 Jan Engelhardt <jengelh@inai.de>
- Trim old specfile constructs.
* Thu Jun  4 2020 tiwai@suse.de
- Update to version 1.5:
  tarball created from the official sof-bin git repo, only signed
  firmware files are included at this time.
  Release notes found at:
    https://github.com/thesofproject/sof/releases/tag/v1.5
- Fixed hda-dsp topology files taken from ftp.alsa-project.org
* Thu Feb 13 2020 tiwai@suse.de
- Update to version 1.4.2:
  see https://github.com/thesofproject/sof/releases for details
- Fix broken symlinks in 1.4.2 tarball
* Tue Jan 14 2020 tiwai@suse.de
- Initial version: 1.4.1, taken from the bundled tarball in
  ftp.alsa-project.org
